pyfpdf: FPDF for Python
=======================

`Quick Start <https://github.com/alexanderankin/pyfpdf>`__

PyFPDF is a library for PDF document generation under Python, ported
from PHP (see `FPDF <http://www.fpdf.org/>`__: "Free"-PDF, a well-known
PDFlib-extension replacement with many examples, scripts and
derivatives).

Compared with other PDF libraries, PyFPDF is simple, small and
versatile, with advanced capabilities, and is easy to learn, extend and
maintain.

THIS VERSION IS AN UPDATED VERSION OF THE PyPI 'fpdf' PACKAGE.

Features:
---------

-  Python 2.7 to 3.5 support
-  Unicode (UTF-8) TrueType font subset embedding
-  Internal/External Links
-  PNG, GIF and JPG support (including transparency and alpha channel)
-  Shape, Line Drawing
-  Cell/Multi-cell/Plaintext writing, Automatic page breaks

Installation Instructions:
--------------------------

To get the latest development version you can download the source code
running (for troubleshooting and additional information, see the GitHub
Repository: `fpdf2 <https://github.com/alexanderankin/pyfpdf>`__)

::

      git clone https://github.com/alexanderankin/pyfpdf.git
      cd pyfpdf
      python setup.py install

You can install PyFPDF from PyPI, with easyinstall or from Windows
installers. For example, using pip:

::

      pip install fpdf2

Documentation:
--------------

-  `Read the Docs <https://alexanderankin.github.io/pyfpdf/>`__
-  `FAQ <https://alexanderankin.github.io/pyfpdf/FAQ/index.html>`__
-  `Tutorial <https://alexanderankin.github.io/pyfpdf/Tutorial/index.html>`__ (Spanish translation available)
-  `Reference Manual <https://alexanderankin.github.io/pyfpdf/ReferenceManual/index.html>`__

For further information, see:

-  `documentation home <https://alexanderankin.github.io/pyfpdf/>`__
-  `pdoc documentation home <https://alexanderankin.github.io/pyfpdf/fpdf>`__
-  `documentation home <https://alexanderankin.github.io/pyfpdf/>`__
-  `fpdf library <https://github.com/reingart/pyfpdf>`__ (fpdf v1.x.x).
-  `fpdf library docs <https://pyfpdf.readthedocs.org/en/latest/>`__ (fpdf v1.x.x).
-  `pyfpdf google code archive page <https://code.google.com/archive/redirect/a/code.google.com/p/pyfpdf?movedTo=http:%2F%2Fwww.github.com%2Freingart%2Fpyfpdf>`__ 
